User Guide
==========

.. _installation:

Installation
------------

| Grayskull can be installed with ``pip``:

::

   pip install grayskull

| or with ``conda``, using the ``conda-forge`` channel:

::

   conda install -c conda-forge grayskull

It is also possible to clone the Grayskull repository and install it using ``pip``:

::

   git clone https://github.com/conda-incubator/grayskull.git
   cd grayskull
   pip install -e .



